import { getTranslations } from "next-intl/server";

import Progressbar from "@/components/common/progress-bar";
import BlurFade from "@/components/ui/blur-fade";
import NumberTicker from "@/components/ui/number-ticker";
import ShinyButton from "@/components/ui/shiny-button";

const SubscriptionCard = async () => {
  const t = await getTranslations("UserAccount");

  return (
    <div
      className="overflow-hidden rounded-lg"
      style={{
        boxShadow: "0px 2px 48px 0px #0000000A",
      }}
    >
      <div className="bg-custom-primary-accent p-6">
        <div className="flex items-center justify-between">
          <div className="h-5 w-9 rounded-sm bg-[#606676]" />
          <p className="text-base text-white">{t("CardName")}</p>
        </div>
        <div className="mt-8 text-white">
          <div className="flex flex-col items-end">
            <p className="mb-2 text-sm">{t("AmountPaid")}</p>
            <div className="flex items-center gap-1 text-3xl">
              <NumberTicker
                className="text-white"
                value={226.4}
                decimalPlaces={2}
              />
              $
            </div>
          </div>
        </div>
      </div>
      <div className="flex items-end justify-between bg-white p-6">
        <div>
          <p className="text-sm text-custom-fourth">**** 4827</p>
        </div>
        <div className="flex flex-col items-end">
          <p className="mb-2 text-sm text-custom-fifth">04/25</p>
          <p className="text-sm text-custom-fourth">{t("SubscriptionDate")}</p>
        </div>
      </div>
    </div>
  );
};

type SubscriptionInfoType = {
  name: string;
};

const SubscriptionInfo = async ({ name }: SubscriptionInfoType) => {
  const t = await getTranslations("UserAccount");

  return (
    <div className="flex flex-col justify-between md:flex-row">
      {/* //TODO left */}
      <div className="flex-1">
        <ShinyButton className="mb-14 bg-[#2895C8]">
          <p className="text-white">{t("AddNewCardButton")}</p>
        </ShinyButton>
        <Progressbar
          progress={60}
          progressColor="#2895C8"
          leftText="16 of 30 Days"
          rightText={t("DaysRemainingPackage")}
          className="mb-4 max-w-80 text-custom-fourth"
        />

        <p className="mb-7 text-[12px] text-custom-fifth">14 {t("DaysLeft")}</p>

        <div className="flex items-center gap-5">
          <ShinyButton className="rounded-[6px] bg-custom-primary-accent py-2">
            <p className="text-[14px] text-white">{t("AutomaticRenewal")}</p>
          </ShinyButton>
          <ShinyButton className="rounded-[6px] bg-[#E9ECEF] py-2 text-[14px] text-[#6C757D]">
            {t("CancelCurrentSubscription")}
          </ShinyButton>
        </div>
      </div>

      {/* //TODO RIGHT */}

      <div className="mt-8 flex flex-1 flex-col items-end">
        <p className="mb-4 text-base">
          {t("CurrentSubscription")} {name}
        </p>
        <div className="mb-4 flex flex-col items-end text-sm">
          <p className="mb-1 text-[14px] text-custom-fourth">
            Active until Apr 09, 2023
          </p>
          <p className="text-custom-fifth">
            {t("SendEmailPackageSubscriptionExpires")}
          </p>
        </div>
        <div className="mb-4 flex flex-col items-end text-sm">
          <div className="mb-1 flex items-center gap-12">
            <div className="rounded-2xl bg-[#606676] px-3 py-0.5 text-[12px] text-white">
              {t("PackageName")}
            </div>
            <p className="mb-1 text-[14px] text-custom-fourth">
              ${" "}
              <NumberTicker
                className="text-custom-fourth"
                value={226.4}
                decimalPlaces={2}
              />{" "}
              {t("Monthly")}
            </p>
          </div>
          <p className="text-custom-fifth">{t("PackageMediumSmallSize")}</p>
        </div>
        <div className="flex flex-col items-end text-sm">
          <div className="mb-1 flex items-center gap-1">
            <div className="rounded-2xl bg-custom-primary-accent px-3 py-0.5 text-[12px] text-white">
              Visa
            </div>
            <p className="mb-1 text-base text-custom-fourth">
              **** **** **** **48
            </p>
          </div>
          <p className="text-custom-fifth">
            {t("CardNumberUsedDuringPurchase")}
          </p>
        </div>
      </div>
    </div>
  );
};

type ActivePlanInfoType = {
  name: string;
  className?: string;
};

function ActivePlanInfo({ name, className }: ActivePlanInfoType) {
  return (
    <BlurFade
      delay={0.25}
      inView
      className={`flex w-full flex-col items-stretch gap-12 lg:flex-row ${className}`}
    >
      <div className="flex-[40%]">
        <SubscriptionCard />
      </div>
      <div className="flex flex-[60%] flex-col">
        <SubscriptionInfo name={name} />
      </div>
    </BlurFade>
  );
}

export default ActivePlanInfo;
